# nextrpg

[![CI](https://github.com/yx-z/nextrpg/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/yx-z/nextrpg/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/yx-z/nextrpg/branch/main/graph/badge.svg)](https://codecov.io/gh/yx-z/nextrpg)
![Python ≥3.12](https://img.shields.io/badge/python-%E2%89%A53.12-blue.svg)
![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)

Build your next RPG (Role Playing Game).

[https://yx-z.github.io/nextrpg/nextrpg.html](https://yx-z.github.io/nextrpg/nextrpg.html)

## Installation

```bash
pip install nextrpg
```

## Example

Work in progress.

## Features

Work in progress.

## License

This project is licensed under the MIT License - see the LICENSE file for
details. 